pub struct SyncResponseModel {
pub object: Option<String>,
pub profile: Option<Box<ProfileResponseModel>>,
pub folders: Option<Vec<FolderResponseModel>>,
pub collections: Option<Vec<CollectionDetailsResponseModel>>,
pub ciphers: Option<Vec<CipherDetailsResponseModel>>,
pub domains: Option<Box<DomainsResponseModel>>,
pub policies: Option<Vec<PolicyResponseModel>>,
pub policies_new: Option<Vec<PolicyResponseModel>>,
pub organizations_new: Option<Vec<ProfileOrganizationResponseModel>>,
pub sends: Option<Vec<SendResponseModel>>,
pub user_decryption: Option<Box<UserDecryptionResponseModel>>,
}Fields
object: Option<String>profile: Option<Box<ProfileResponseModel>>folders: Option<Vec<FolderResponseModel>>collections: Option<Vec<CollectionDetailsResponseModel>>ciphers: Option<Vec<CipherDetailsResponseModel>>domains: Option<Box<DomainsResponseModel>>policies: Option<Vec<PolicyResponseModel>>policies_new: Option<Vec<PolicyResponseModel>>Policies for organizations where the user is in the Confirmed or Accepted status. Null when
the pm-34145-policies-in-accepted-state feature flag is disabled. New clients should
prefer this property and fall back to
Bit.Api.Vault.Models.Response.SyncResponseModel.Policies if absent.
organizations_new: Option<Vec<ProfileOrganizationResponseModel>>Organizations where the user is in the Confirmed or Accepted status. Null when the
pm-34145-policies-in-accepted-state feature flag is disabled. New clients should prefer
this property and fall back to
Bit.Api.Vault.Models.Response.SyncResponseModel.Profile.Organizations if absent.
sends: Option<Vec<SendResponseModel>>user_decryption: Option<Box<UserDecryptionResponseModel>>Implementations
Sourceimpl SyncResponseModel
impl SyncResponseModel
pub fn new() -> SyncResponseModel